@@ -9,15 +9,15 @@ use Data::Object;
 use Data::Object::Signatures;
 use Readonly;
 
-our $VERSION = '0.07'; # VERSION
+our $VERSION = '0.08'; # VERSION
 
 method new ($data) {
 
     $self = Data::Object->new($data);
 
-    Readonly::Hash   %$self => %$self if UNIVERSAL::isa($self, 'HASH');
-    Readonly::Array  @$self => @$self if UNIVERSAL::isa($self, 'ARRAY');
-    Readonly::Scalar $$self => $$self if UNIVERSAL::isa($self, 'SCALAR');
+    Readonly::Hash   %$self => %$self if UNIVERSAL::isa $self, 'HASH';
+    Readonly::Array  @$self => @$self if UNIVERSAL::isa $self, 'ARRAY';
+    Readonly::Scalar $$self => $$self if UNIVERSAL::isa $self, 'SCALAR';
 
     return $self;
 
@@ -37,7 +37,7 @@ Data::Object::Immutable - Immutable Object for Perl 5
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 SYNOPSIS
 
@@ -62,6 +62,12 @@ security than mutable objects.
 
 Al Newkirk <anewkirk@ana.io>
 
+=head1 CONTRIBUTOR
+
+=for stopwords Developer
+
+Developer <dev@example.com>
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2014 by Al Newkirk.
