@@ -11,11 +11,13 @@ use Data::Object::Signatures;
 use Data::Object::Immutable;
 use Readonly;
 
-our $VERSION = '0.07'; # VERSION
+our $VERSION = '0.08'; # VERSION
 
 around BUILD => fun ($orig, $self, @args) {
 
-    return Data::Object::Immutable->new($self->$orig(@args));
+    my $result = $self->$orig(@args);
+
+    return Data::Object::Immutable->new($result);
 
 };
 
@@ -33,7 +35,7 @@ Data::Object::Role::Immutable - Immutable Object Role for Perl 5
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 SYNOPSIS
 
